@@ -204,19 +204,21 @@ def rotate(
                 total=total_frames,
                 desc="Rendering frames",
                 disable=not verbose,
+                dynamic_ncols=True,
                 leave=False
             )
             for executed_tasks_number in p.imap(_render_frame_wrapper, chunks(tasks, chunks_size)):
                 loading_bar.update(executed_tasks_number)
+            loading_bar.close()
             p.close()
             p.join()
     else:
-        for task in tqdm(tasks, desc="Rendering frames", disable=not verbose, leave=False):
+        for task in tqdm(tasks, desc="Rendering frames", disable=not verbose, dynamic_ncols=True, leave=False):
             _render_frame_wrapper([task])
 
     if is_gif:
         with imageio.get_writer(path, mode='I', fps=fps) as writer:
-            for task in tqdm(tasks, desc="Merging frames", disable=not verbose, leave=False):
+            for task in tqdm(tasks, desc="Merging frames", disable=not verbose, dynamic_ncols=True, leave=False):
                 writer.append_data(imageio.imread(task[-1]))
         optimize(path)
     else:
